@@ -15,6 +15,7 @@ if __name__ == '__main__':
     inject.config = sys.argv[1]
     logging.debug("config: %s", inject.config)
     workspace = Workspace()
+    workspace.unregister_agents()
     workspace.publish()
     workspace.publish_agents()
     logger.debug(workspace.address)
@@ -30,4 +31,6 @@ if __name__ == '__main__':
             pass
     logger.debug("elapsed time: %s seconds",time() - start_time)
     workspace.daemon.close()
+    workspace.unregister_agents()
+    workspace.unregister()
 
